@@ -1,9 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "keytar" "0.1.2"
+(define-package "keytar" "20251231.1727"
   "Emacs Lisp interface for node-keytar."
   '((emacs "24.4"))
   :url "https://github.com/emacs-grammarly/keytar"
-  :commit "17972320ef140bd56e551842d89f5d8c2d979f83"
-  :revdesc "17972320ef14"
+  :commit "f0485df065bcdc8f446be3e00aa77a43629ec84e"
+  :revdesc "f0485df065bc"
+  :keywords '("convenience" "keytar" "password" "credential" "secret" "security")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
